topsbm - A scikit-learn extension for Topic Models based on Stochastic Block Models
===================================================================================

|version| |docs| |licence|

|issues| |build| |coverage|


Martin Gerlach, Tiago P. Peixoto, and Eduardo G. Altmann, `“A network approach to topic models,” <http://advances.sciencemag.org/content/4/7/eaaq1360>`_ Science Advances (2018)

Software ported to Scikit-learn format by the `Sydney Informatics Hub <https://informatics.sydney.edu.au>`__ at the University of Sydney.

.. |py-versions| image:: https://img.shields.io/pypi/pyversions/topsbm.svg
    :alt: Python versions supported

.. |version| image:: https://badge.fury.io/py/topsbm.svg
    :alt: Latest version on PyPi
    :target: https://badge.fury.io/py/topsbm

.. |build| image:: https://travis-ci.org/Sydney-Informatics-Hub/topsbm.svg?branch=master
    :alt: Travis CI build status
    :scale: 100%
    :target: https://travis-ci.org/Sydney-Informatics-Hub/topsbm

.. |issues| image:: https://img.shields.io/github/issues/Sydney-Informatics-Hub/topsbm.svg
    :alt: Issue tracker
    :target: https://github.com/Sydney-Informatics-Hub/topsbm

.. |coverage| image:: https://coveralls.io/repos/github/Sydney-Informatics-Hub/topsbm/badge.svg
    :alt: Test coverage
    :target: https://coveralls.io/github/Sydney-Informatics-Hub/topsbm

.. |docs| image:: https://readthedocs.org/projects/topsbm/badge/?version=latest
     :alt: Documentation Status
     :scale: 100%
     :target: https://topsbm.readthedocs.io/en/latest/?badge=latest

.. |licence| image:: https://img.shields.io/badge/Licence-GPLv3-blue.svg
     :target: https://opensource.org/licenses/gpl-license
